---
Title: Scientific targets
Author: Jannik
status: reviewed
Reviewer: Tamas
Comment: Mainly based on LoI and Infradev Grant Agreement
---

# Science in KM3NeT

## Scientific Targets

The KM3NeT neutrino detectors will continuously register neutrinos from the whole sky. The neutrinos of astrophysical interest, i.e. those from extra-terrestrial origin, need to be identified in the background of atmospheric neutrinos, i.e. those created in Earth’s atmosphere by interactions of cosmic-ray particles. Access to cosmic neutrino data is of high importance for a wide astrophysics community to relate cosmic neutrino fluxes to observations by other neutrino observatories or using [other messengers](Multimessengers.md), and to compare them with theoretical predictions. The atmospheric neutrinos carry information on the particle physics processes in which they are created and on the neutrinos themselves. These data are relevant for a wide astroparticle and particle physics community. Finally, KM3NeT will monitor marine parameters, such as bioluminescence, currents, water properties and transient acoustic signals and provides user ports for Earth and Sea sciences.


### Astro Physics

The main science objective of KM3NeT/ARCA is the detection of high-energy neutrinos of cosmic origin. Neutrinos represent an alternative to photons and cosmic rays to explore the high-energy Universe. Neutrinos can emerge from dense objects and travel large distances, without being deflected by magnetic fields or interacting with radiation and matter. Thus, even modest numbers of detected neutrinos can be of utmost scientific relevance, by indicating the astrophysical objects in which cosmic rays are accelerated, or pointing to places where dark matter particles annihilate or decay. 

The detector design of the KM3NeT/ARCA has been optimised to target astrophysical neutrinos at TeV energies and above in order to maximise the sensitivity to detect neutrinos from the cosmic ray accelerators in our Galaxy. In a neutrino telescope like ARCA, two main event topologies can be identified: Firstly, the 'track' topology indicates the presence of muons produced in charged current muon neutrino interactions and tau neutrino interactions with muonic tau decays. Muons are the only class of particles that can be confidently identified, because they are the only particles that appear as tracks in the detector. Secondly, the shower topology refers to a point-like particle shower from neutral current interactions of all three neutrino flavours, the charge current interactions of electron neutrino and tau neutrino interactions with non-muonic tau decays. For tau neutrinos at sufficiently high energies (E > 100TeV), the produced tau lepton can travel several metres before decaying, resulting in distinguishable two individual showers. This allows identification of tau neutrinos with a clear signature of the flavour of the neutrino primaries. All neutrino flavours can be used for neutrino astronomy.

The preferred search strategy is to identify upward-moving tracks, which unambiguously indicates neutrino reactions since only neutrinos can traverse the Earth without being absorbed. A neutrino telescope in the Mediterranean Sea on the Northern hemisphere of the Earth is well suited for this purpose, since most of the potential Galactic sources are in the Southern sky. 

Besides all-favour neutrino astronomy, i.e. investigating high-energy cosmic neutrinos and identifying their astrophysical sources, additional physics topics of ARCA include

- [multi-messenger studies](Multimessengers.md)
- particle physics with atmospheric muons and neutrinos
- indirect searches for dark matter

The ARCA detector allows to reconstruct the arrival direction of TeV-PeV neutrinos to sub-degree resolution for track-like events and ~2 degree for shower-like events. The energy resolution is about ~0.27 in log10(E_\mu) for muons above 10TeV, while for showers a ~5% resolution on the visible energy is achieved. In order to achieve these resolutions, typically a set of quality selection criteria are applied based on the output of the event reconstructions. 

Further details on the detector performance can be found in [1].


### Neutrino Physics

Neutrinos have the peculiar feature that they can change from one flavour to another when propagating over macroscopic distances. This phenomenon of neutrino flavour change is known as 'neutrino oscillation'. The Nobel Prize in Physics of the year 2015 was awarded to T. Kajita and A. B. McDonald for the discovery of neutrino oscillations, which shows that neutrinos have mass [1]. One open question is the so-called 'neutrino mass ordering'. It refers to the sign of one of the two independent neutrino mass differences, the absolute value of which has already been known for more than two decades.

The main science objective of KM3NeT/ORCA is the determination of the ordering of the three neutrino mass eigenstates by measuring the oscillation pattern of atmospheric neutrinos. Atmospheric neutrinos are produced in cosmic-ray air-showers in the Earth atmosphere. When produced on the other side of the Earth and traversing the Earth towards the detector, atmospheric neutrinos oscillate, ie. change their flavour between production and detection. The oscillation pattern in the few-GeV energy range is sensitive to the neutrino mass ordering and other oscillation parameters.

Besides determining the neutrino mass ordering, additional science topics of ORCA include:

- testing the unitary of the neutrino mixing matrix by studying tau-neutrino appearance
- indirect searches for sterile neutrinos, non-standard interactions and other exotic physics
- indirect searches for dark matter; testing the chemical composition of the Earth's core (Earth tomography)
- low-energy neutrino astrophysics

The detector design of the KM3NeT/ORCA has been optimised for atmospheric neutrinos in the 1-100GeV energy range in order to maximise the sensitivity of determining the neutrino mass ordering. For neutrino oscillation measurements with KM3NeT/ORCA, the capability to differentiate the two event topologies -- i.e. the track-shower separation power -- is very important.

The detector performance of the ORCA detector is summarised in detail in [1].


-----------
[1] [Adrian-Martnez S et al (KM3NeT Collaboration) 2016 J. Phys. G 43 084001](https://iopscience.iop.org/article/10.1088/0954-3899/43/8/084001)    

